@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2019 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -21,12 +21,12 @@
 */
 
 #include "webwidget.h"
+#include "webselecttypecombobox.h"
 #include <QHBoxLayout>
 #include <QToolButton>
 #include <QUrl>
 #include <KLocalizedString>
 #include <editor/widgets/preferredlineeditwidget.h>
-#include <editor/generalinfoeditor/contactselecttypecombobox.h>
 using namespace ContactEditor;
 
 WebWidget::WebWidget(QWidget *parent)
@@ -34,7 +34,7 @@ WebWidget::WebWidget(QWidget *parent)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mWebSiteEdit = new PreferredLineEditWidget(this);
     mWebSiteEdit->setTrapReturnKey(true);
@@ -43,8 +43,9 @@ WebWidget::WebWidget(QWidget *parent)
     layout->addWidget(mWebSiteEdit);
     connect(mWebSiteEdit, &PreferredLineEditWidget::preferredChanged, this, &WebWidget::slotPreferredChanged);
 
-    mWebType = new ContactEditor::ContactSelectTypeCombobox(this);
+    mWebType = new ContactEditor::WebSelectTypeCombobox(this);
     mWebType->setObjectName(QStringLiteral("webtype"));
+    mWebType->initialize();
     layout->addWidget(mWebType);
 
     mAddButton = new QToolButton(this);
@@ -111,7 +112,7 @@ KContacts::ResourceLocatorUrl WebWidget::url()
     }
     if (mWebSiteEdit->preferred()) {
         if (!value.contains(QLatin1String("PREF"))) {
-            value.append(QLatin1String("PREF"));
+            value.append(QStringLiteral("PREF"));
         }
     } else {
         value.removeAll(QStringLiteral("PREF"));
